# An event-bus application layer, support redis

## Install
```pip install aiobus```

## Running tests
Before to run tests you should 
 - install dependencies: ```pip install -r requirements.txt```
 - start the dependent services with command: ```docker-compose up -d```